@@ -113,7 +113,7 @@ file_sel_response_cb (GtkWidget    *widget,
 		char      *utf8_path;
 		char      *message;
 
-		utf8_path = g_filename_to_utf8 (current_folder, -1, NULL, NULL, NULL);
+		utf8_path = g_filename_display_name (current_folder);
 		message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
 		g_free (utf8_path);
 
@@ -242,7 +242,7 @@ selection_changed_cb (GtkWidget  *file_sel,
                 char      *utf8_path;
                 char      *message;
 		
-                utf8_path = g_filename_to_utf8 (current_folder, -1, NULL, NULL, NULL);
+                utf8_path = g_filename_display_name (current_folder);
                 message = g_strdup_printf (_("You don't have the right permissions to read files from folder \"%s\""), utf8_path);
                 g_free (utf8_path);
 		
@@ -549,10 +549,10 @@ aod_apply_cb (GtkWidget *widget,
 
 	if (base_dir != NULL)
 		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (data->dialog), base_dir);
-	/* FIXME
+
 	if (filename != NULL)
-		gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (data->dialog), filename);
-	*/
+		gtk_file_chooser_select_filename (GTK_FILE_CHOOSER (data->dialog), filename);
+
 	if (include_files != NULL)
 		gtk_entry_set_text (GTK_ENTRY (data->include_files_entry), include_files);
 	if (exclude_files != NULL)
