@@ -468,8 +468,9 @@ process_output (FRProcess *fr_proc)
 		fr_proc->raw_output = g_list_prepend (fr_proc->raw_output, 
 						      g_strdup (line));
 
-		if (fr_proc->o_proc_line_func != NULL)
+		if ((fr_proc->o_proc_line_func != NULL) && (line != NULL)) {
 			(*fr_proc->o_proc_line_func) (line, fr_proc->o_proc_line_data);
+		}
 
 		line = eol + 1;
 	}
@@ -510,8 +511,9 @@ process_error (FRProcess *fr_proc)
 		fr_proc->raw_error = g_list_prepend (fr_proc->raw_error, 
 						     g_strdup (line));
 
-		if (fr_proc->e_proc_line_func != NULL)
+		if ((fr_proc->e_proc_line_func != NULL) && (line != NULL)) {
 			(*fr_proc->e_proc_line_func) (line, fr_proc->e_proc_line_data);
+		}
 
 		line = eol + 1;
 	}
